       function [srkm,eca,hrng] =  elv2geom(elv,alt)
%
%         elevation angle to geometry
%    
%    input:
%              elv       elevation angle deg
%              alt       altitude in km
%
%    output:
%              srkm      slant range in km 
%              eca       earth central angle in deg
%              hrng      horizontal range along earth
%
%         used  6378 km  as earth radius 
%
     elvr = (pi/180.0) * elv ;
%
     rearth =  6378.;
     res    =  rearth*rearth;
%
     ralt   = rearth + alt;
     ralts  = ralt.*ralt;
%
     beta   = elvr + pi/2.0;
     cbeta  = cos(beta);
     rcb    = rearth*cbeta;
     dissq  = rcb.*rcb + ralts - res;
     s      = rcb + sqrt ( dissq );
%
     num    = res + ralts - s.*s;
     dom    = 2.0*rearth*ralt;
     ctheta = num./dom;
%
     thetar = acos(ctheta);
%
     srkm   =  s;
     eca    =  thetar*180.0/pi;
     hrng   = rearth * thetar;
%
